@@ -2,6 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
+from trytond.pyson import PYSONEncoder
 
 
 class ProductCostHistory(ModelSQL, ModelView):
@@ -55,21 +56,20 @@ class OpenProductCostHistory(Wizard):
         model_data_obj = self.pool.get('ir.model.data')
         act_window_obj = self.pool.get('ir.action.act_window')
         product_obj = self.pool.get('product.product')
-
-        model_data_ids = model_data_obj.search(cursor, user, [
-            ('fs_id', '=', 'act_product_cost_history_form'),
-            ('module', '=', 'product_cost_history'),
-            ('inherit', '=', False),
-            ], limit=1, context=context)
-        model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
+        act_window_id = model_data_obj.get_id(cursor, user,
+                'product_cost_history', 'act_product_cost_history_form',
                 context=context)
-        res = act_window_obj.read(cursor, user, model_data.db_id, context=context)
+        res = act_window_obj.read(cursor, user, act_window_id, context=context)
 
         if not data['id'] or data['id'] < 0:
-            res['domain'] = str([('template', '=', False)])
+            res['pyson_domain'] = PYSONEncoder().encode([
+                ('template', '=', False),
+            ])
         else:
             product = product_obj.browse(cursor, user, data['id'], context=context)
-            res['domain'] = str([('template', '=', product.template.id)])
+            res['pyson_domain'] = PYSONEncoder().encode([
+                ('template', '=', product.template.id),
+            ])
         return res
 
 OpenProductCostHistory()
